@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package App::Cmd::Tester;
-$App::Cmd::Tester::VERSION = '0.333';
+package App::Cmd::Tester 0.337;
+
 # ABSTRACT: for capturing the result of running an app
 
 #pod =head1 SYNOPSIS
@@ -138,9 +138,9 @@ sub _run_with_capture {
 }
 
 {
-  package App::Cmd::Tester::Result;
-$App::Cmd::Tester::Result::VERSION = '0.333';
-sub new {
+  package App::Cmd::Tester::Result 0.337;
+
+  sub new {
     my ($class, $arg) = @_;
     bless $arg => $class;
   }
@@ -154,9 +154,9 @@ sub new {
 }
 
 {
-  package App::Cmd::Tester::Exited;
-$App::Cmd::Tester::Exited::VERSION = '0.333';
-sub throw {
+  package App::Cmd::Tester::Exited 0.337;
+
+  sub throw {
     my ($class, $code) = @_;
     $code = 0 unless defined $code;
     my $self = (bless \$code => $class);
@@ -178,7 +178,7 @@ App::Cmd::Tester - for capturing the result of running an app
 
 =head1 VERSION
 
-version 0.333
+version 0.337
 
 =head1 SYNOPSIS
 
@@ -207,6 +207,16 @@ provides to help make it easy to test App::Cmd-based programs.
 
 It provides one routine: test_app.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 METHODS
 
 =head2 test_app
@@ -241,11 +251,11 @@ L<App::Cmd::Tester::CaptureExternal> instead.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2024 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
