@@ -3,6 +3,6 @@ package Test::MyCmdAbbrev::Command::foo;
 use strict;
 use warnings;
 
-use base qw{ App::Cmd::Command };
+use parent qw{ App::Cmd::Command };
 
 1;
